==> py-gtkscintilla-0.3.tgz: lib/python2.0/site-packages/GTKSCINTILLA.py <==
# GTKSCINTILLA.py - constants for gtkscintilla.py
#
# Copyright (c) 2001  Michele Campeotto <micampe@f2s.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.


# GtkScintillaEolMode
EOL_CRLF = 0
EOL_CR   = 1
EOL_LF   = 2

# GtkScintillaMarginType
MARGIN_SYMBOL = 0
MARGIN_NUMBER = 1

# GtkScintillaEdgeMode
EDGE_NONE       = 0
EDGE_LINE       = 1
EDGE_BACKGROUND = 2

# Find flags
FIND_DOWN        = 1 << 0
FIND_WHOLE_WORDS = 1 << 1
FIND_MATCH_CASE  = 1 << 2
FIND_FROM_TOP    = 1 << 3

# GtkScintillaLexer
LEXER_CONTAINER  = 0
LEXER_NULL       = 1
LEXER_PYTHON     = 2
LEXER_CPP        = 3
LEXER_HTML       = 4
LEXER_XML        = 5
LEXER_PERL       = 6
LEXER_SQL        = 7
LEXER_VB         = 8
LEXER_PROPERTIES = 9
LEXER_ERRORLIST  = 10
LEXER_MAKEFILE   = 11
LEXER_BATCH      = 12
LEXER_XCODE      = 13
LEXER_LATEX      = 14
LEXER_LUA        = 15
LEXER_DIFF       = 16
LEXER_CONF       = 17
LEXER_PASCAL     = 18

# GtkScintillaStyle
STYLE_DEFAULT      = 32
STYLE_LINE_NUMBER  = 33
STYLE_BRACE_LIGHT  = 34
STYLE_BRACE_BAD    = 35
STYLE_CONTROL_CHAR = 36
STYLE_INDENT_GUIDE = 37
STYLE_MAX          = 127

# LEXER_PYTHON lexical states
PYTHON_WHITE_SPACE     = 0
PYTHON_COMMENT_LINE    = 1
PYTHON_NUMBER          = 2
PYTHON_STRING_DOUBLE   = 3
PYTHON_STRING_SINGLE   = 4
PYTHON_KEYWORD         = 5
PYTHON_TRIPLE_SINGLE   = 6
PYTHON_TRIPLE_DOUBLE   = 7
PYTHON_CLASS_STATEMENT = 8
PYTHON_DEF_STATEMENT   = 9
PYTHON_OPERATOR        = 10
PYTHON_IDENTIFIER      = 11
PYTHON_COMMENT_BLOCK   = 12
PYTHON_STRING_EOL      = 13

# LEXER_CPP Lexical states
CPP_WHITE_SPACE     = 0
CPP_COMMENT_BLOCK   = 1
CPP_COMMENT_LINE    = 2
CPP_COMMENT_DOC     = 3
CPP_NUMBER          = 4
CPP_KEYWORD         = 5
CPP_STRING          = 6
CPP_CHARACTER       = 7
CPP_UUID            = 8
CPP_PREPROCESSOR    = 9
CPP_OPERATOR        = 10
CPP_IDENTIFIER      = 11
CPP_STRING_EOL      = 12
CPP_STRING_VERBATIM = 13

# LEXER_HTML Lexical states
HTML_TEXT               = 0
HTML_TAG                = 1
HTML_TAG_UNKNOWN        = 2
HTML_ATTRIBUTE          = 3
HTML_ATTRIBUTE_UNKNOWN  = 4
HTML_NUMBER             = 5
HTML_DOUBLE_STRING      = 6
HTML_SINGLE_STRING      = 7
HTML_OTHER              = 8
HTML_COMMENT            = 9
HTML_ENTITY             = 10
HTML_XML_TAG_END        = 11    # XML style tag ends '/>'
HTML_XML_ID_START       = 12    # XML identifier start '<?'
HTML_XML_ID_END         = 13    # XML identifier end '?>'
HTML_SCRIPT             = 14
HTML_ASP_1              = 15    # ASP <% ... %>
HTML_ASP_2              = 16    # ASP <% ... %>
HTML_CDATA              = 17
HTML_PHP                = 18
HTML_UNQUOTED           = 19

# LEXER HTML :: Embedded Javascript
HTML_JS_START           = 40
HTML_JS_DEFAULT         = 41
HTML_JS_COMMENT_BLOCK   = 42
HTML_JS_COMMENT_LINE    = 43
HTML_JS_COMMENT_DOC     = 44
HTML_JS_NUMBER          = 45
HTML_JS_WORD            = 46
HTML_JS_KEYWORD         = 47
HTML_JS_STRING_DOUBLE   = 48
HTML_JS_STRING_SINGLE   = 49
HTML_JS_SYMBOL          = 50
HTML_JS_EOL             = 51

# LEXER_HTML :: ASP Javascript
HTML_ASPJS_START            = 55
HTML_ASPJS_DEFAULT          = 56
HTML_ASPJS_COMMENT_BLOCK    = 57
HTML_ASPJS_COMMENT_LINE     = 58
HTML_ASPJS_COMMENT_DOC      = 59
HTML_ASPJS_NUMBER           = 60
HTML_ASPJS_WORD             = 61
HTML_ASPJS_KEYWORD          = 62
HTML_ASPJS_STRING_DOUBLE    = 63
HTML_ASPJS_STRING_SINGLE    = 64
HTML_ASPJS_SYMBOL           = 65
HTML_ASPJS_EOL              = 66

# LEXER_HTML :: Embedded VBS
HTML_VBS_START      = 70
HTML_VBS_DEFAULT    = 71
HTML_VBS_COMMENT    = 72
HTML_VBS_NUMBER     = 73
HTML_VBS_KEYWORD    = 74
HTML_VBS_STRING     = 75
HTML_VBS_IDENTIFIER = 76
HTML_VBS_EOL        = 77

# LEXER_HTML :: ASP VBS
HTML_ASPVBS_START       = 80
HTML_ASPVBS_DEFAULT     = 81
HTML_ASPVBS_COMMENT     = 82
HTML_ASPVBS_NUMBER      = 83
HTML_ASPVBS_KEYWORD     = 84
HTML_ASPVBS_STRING      = 85
HTML_ASPVBS_IDENTIFIER  = 86
HTML_ASPVBS_EOL         = 87

# LEXER_HTML :: Embedded Python
HTML_PY_90              = 90    # What are these styles?
HTML_PY_91              = 91    # Should look in Scintilla's code
HTML_PY_COMMENT_LINE    = 92
HTML_PY_NUMBER          = 93
HTML_PY_STRING_DOUBLE   = 94
HTML_PY_STRING_SINGLE   = 95
HTML_PY_KEYWORD         = 96
HTML_PY_TRIPLE_SINGLE   = 97
HTML_PY_TRIPLE_DOUBLE   = 98
HTML_PY_CLASS_STATEMENT = 99
HTML_PY_DEF_STATEMENT   = 100
HTML_PY_OPERATOR        = 101
HTML_PY_IDENTIFIER      = 102

# LEXER_HTML :: ASP Python
HTML_ASPPY_105             = 105    # What are these styles?
HTML_ASPPY_106             = 106    # Should look in Scintilla's code
HTML_ASPPY_COMMENT_LINE    = 107
HTML_ASPPY_NUMBER          = 108
HTML_ASPPY_STRING_DOUBLE   = 109
HTML_ASPPY_STRING_SINGLE   = 110
HTML_ASPPY_KEYWORD         = 111
HTML_ASPPY_TRIPLE_SINGLE   = 112
HTML_ASPPY_TRIPLE_DOUBLE   = 113
HTML_ASPPY_CLASS_STATEMENT = 114
HTML_ASPPY_DEF_STATEMENT   = 115
HTML_ASPPY_OPERATOR        = 116
HTML_ASPPY_IDENTIFIER      = 117

# LEXER_HTML :: PHP
HTML_PHP_DEFAULT        = 118
HTML_PHP_STRING_DOUBLE  = 119
HTML_PHP_STRING_SINGLE  = 120
HTML_PHP_KEYWORD        = 121
HTML_PHP_NUMBER         = 122
HTML_PHP_VARIABLE       = 123
HTML_PHP_COMMENT_BLOCK  = 124
HTML_PHP_COMMENT_LINE   = 125
HTML_PHP_EOL            = 126

# LEXER_XML Lexical states
XML_DEFAULT             = 0
XML_TAG                 = 1
XML_TAG_UNKNOWN         = 2
XML_ATTRIBUTE           = 3
XML_ATTRIBUTE_UNKNOWN   = 4
XML_NUMBER              = 5
XML_DOUBLE_STRING       = 6
XML_SINGLE_STRING       = 7
XML_OTHER               = 8
XML_COMMENT             = 9
XML_ENTITY              = 10
XML_TAG_END             = 11
XML_ID_START            = 12
XML_ID_END              = 13
XML_CDATA               = 17
XML_QUESTION            = 18
XML_UNQUOTED            = 19

# LEXER_PERL Lexical states
PERL_WHITE_SPACE     = 0
PERL_ERROR           = 1
PERL_COMMENT_LINE    = 2
PERL_POD             = 3
PERL_NUMBER          = 4
PERL_KEYWORD         = 5
PERL_STRING          = 6
PERL_CHARACTER       = 7
PERL_PUNCTUATION     = 8
PERL_PREPROCESSOR    = 9
PERL_OPERATOR        = 10
PERL_IDENTIFIER      = 11
PERL_SCALAR          = 12
PERL_ARRAY           = 13
PERL_HASH            = 14
PERL_SYMBOL_TABLE    = 15
PERL_REF             = 16
PERL_REGEX           = 17
PERL_REGSUBST        = 18
PERL_LONG_QUOTE      = 19
PERL_BACKTICKS       = 20
PERL_DATA_SECTION    = 21
PERL_DATA_HERE_DELIM = 22
PERL_DATA_HERE_Q     = 23
PERL_DATA_HERE_QQ    = 24
PERL_DATA_HERE_QX    = 25

# LEXER_SQL Lexical states
SQL_WHITE_SPACE   = 0
SQL_COMMENT_BLOCK = 1
SQL_COMMENT_LINE  = 2
SQL_COMMENT_DOC   = 3
SQL_NUMBER        = 4
SQL_KEYWORD       = 5
SQL_DOUBLE_STRING = 6
SQL_SINGLE_STRING = 7
SQL_SYMBOLS       = 8
SQL_PREPROCESSOR  = 9
SQL_OPERATOR      = 10
SQL_IDENTIFIER    = 11
SQL_STRING_EOL    = 12

# LEXER_VB Lexical states
VB_WHITE_SPACE   = 0
VB_COMMENT_BLOCK = 1
VB_COMMENT_LINE  = 2
VB_COMMENT_DOC   = 3
VB_NUMBER        = 4
VB_WORD          = 5
VB_STRING        = 6
VB_CHARACTER     = 7
VB_UUID          = 8
VB_PREPROCESSOR  = 9
VB_OPERATOR      = 10
VB_IDENTIFIER    = 11
VB_STRING_EOL    = 12

# LEXER_MAKEFILE Lexical states
MAKEFILE_WHITE_SPACE = 0
MAKEFILE_COMMENT     = 1

# LEXER_LATEX Lexical states
LATEX_WHITE_SPACE = 0
LATEX_COMMAND     = 1
LATEX_TAG         = 2
LATEX_MATH        = 3
LATEX_COMMENT     = 4

# LEXER_LUA Lexical states
LUA_WHITE_SPACE    = 0
LUA_COMMENT_BLOCK  = 1
LUA_COMMENT_LINE   = 2
LUA_COMMENT_DOC    = 3
LUA_NUMBER         = 4
LUA_KEYWORD        = 5
LUA_STRING         = 6
LUA_CHARACTER      = 7
LUA_LITERAL_STRING = 8
LUA_PREPROCESSOR   = 9
LUA_OPERATOR       = 10
LUA_IDENTIFIER     = 11
LUA_STRING_EOL     = 12

# LEXER_PASCAL Lexical states
PASCAL_WHITE_SPACE   = 0
PASCAL_COMMENT_BLOCK = 1
PASCAL_COMMENT_LINE  = 2
PASCAL_COMMENT_DOC   = 3
PASCAL_NUMBER        = 4
PASCAL_KEYWORD       = 5
PASCAL_DOUBLE_STRING = 6
PASCAL_SINGLE_STRING = 7
PASCAL_SYMBOLS       = 8
PASCAL_PREPROCESSOR  = 9

==> py-gtkscintilla-0.7.3.tgz: lib/python2.1/site-packages/GTKSCINTILLA.py <==
# GTKSCINTILLA.py - constants for gtkscintilla.py
#
# Copyright (c) 2001  Michele Campeotto <micampe@f2s.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.


INVALID_POSITION = -1

# GtkScintillaEolMode
EOL_CRLF = 0
EOL_CR   = 1
EOL_LF   = 2

# GtkScintillaMarginType
MARGIN_SYMBOL = 0
MARGIN_NUMBER = 1

# GtkScintillaEdgeMode
EDGE_NONE       = 0
EDGE_LINE       = 1
EDGE_BACKGROUND = 2

# Find flags
FIND_DOWN        = 1
FIND_WHOLE_WORDS = 2
FIND_MATCH_CASE  = 4
FIND_WORD_START  = 0x00100000
FIND_REGEXP      = 0x00200000

# GtkScintillaLexer
LEXER_CONTAINER  = 0
LEXER_NULL       = 1
LEXER_PYTHON     = 2
LEXER_CPP        = 3
LEXER_HTML       = 4
LEXER_XML        = 5
LEXER_PERL       = 6
LEXER_SQL        = 7
LEXER_VB         = 8
LEXER_PROPERTIES = 9
LEXER_ERRORLIST  = 10
LEXER_MAKEFILE   = 11
LEXER_BATCH      = 12
LEXER_XCODE      = 13
LEXER_LATEX      = 14
LEXER_LUA        = 15
LEXER_DIFF       = 16
LEXER_CONF       = 17
LEXER_PASCAL     = 18
LEXER_AVE        = 19
LEXER_ADA        = 20

# GtkScintillaStyle
STYLE_DEFAULT      = 32
STYLE_LINE_NUMBER  = 33
STYLE_BRACE_LIGHT  = 34
STYLE_BRACE_BAD    = 35
STYLE_CONTROL_CHAR = 36
STYLE_INDENT_GUIDE = 37
STYLE_MAX          = 127

# LEXER_PYTHON lexical states
PYTHON_WHITE_SPACE     = 0
PYTHON_COMMENT_LINE    = 1
PYTHON_NUMBER          = 2
PYTHON_STRING_DOUBLE   = 3
PYTHON_STRING_SINGLE   = 4
PYTHON_KEYWORD         = 5
PYTHON_TRIPLE_SINGLE   = 6
PYTHON_TRIPLE_DOUBLE   = 7
PYTHON_CLASS_STATEMENT = 8
PYTHON_DEF_STATEMENT   = 9
PYTHON_OPERATOR        = 10
PYTHON_IDENTIFIER      = 11
PYTHON_COMMENT_BLOCK   = 12
PYTHON_STRING_EOL      = 13

# LEXER_CPP Lexical states
CPP_WHITE_SPACE     = 0
CPP_COMMENT_BLOCK   = 1
CPP_COMMENT_LINE    = 2
CPP_COMMENT_DOC     = 3
CPP_NUMBER          = 4
CPP_KEYWORD         = 5
CPP_STRING          = 6
CPP_CHARACTER       = 7
CPP_UUID            = 8
CPP_PREPROCESSOR    = 9
CPP_OPERATOR        = 10
CPP_IDENTIFIER      = 11
CPP_STRING_EOL      = 12
CPP_STRING_VERBATIM = 13

# LEXER_HTML Lexical states
HTML_TEXT               = 0
HTML_TAG                = 1
HTML_TAG_UNKNOWN        = 2
HTML_ATTRIBUTE          = 3
HTML_ATTRIBUTE_UNKNOWN  = 4
HTML_NUMBER             = 5
HTML_DOUBLE_STRING      = 6
HTML_SINGLE_STRING      = 7
HTML_OTHER              = 8
HTML_COMMENT            = 9
HTML_ENTITY             = 10
HTML_XML_TAG_END        = 11    # XML style tag ends '/>'
HTML_XML_ID_START       = 12    # XML identifier start '<?'
HTML_XML_ID_END         = 13    # XML identifier end '?>'
HTML_SCRIPT             = 14
HTML_ASP_1              = 15    # ASP <% ... %>
HTML_ASP_2              = 16    # ASP <% ... %>
HTML_CDATA              = 17
HTML_PHP                = 18
HTML_UNQUOTED           = 19

# LEXER HTML :: Embedded Javascript
HTML_JS_START           = 40
HTML_JS_DEFAULT         = 41
HTML_JS_COMMENT_BLOCK   = 42
HTML_JS_COMMENT_LINE    = 43
HTML_JS_COMMENT_DOC     = 44
HTML_JS_NUMBER          = 45
HTML_JS_WORD            = 46
HTML_JS_KEYWORD         = 47
HTML_JS_STRING_DOUBLE   = 48
HTML_JS_STRING_SINGLE   = 49
HTML_JS_SYMBOL          = 50
HTML_JS_EOL             = 51
HTML_JS_REGEX           = 52

# LEXER_HTML :: ASP Javascript
HTML_ASPJS_START            = 55
HTML_ASPJS_DEFAULT          = 56
HTML_ASPJS_COMMENT_BLOCK    = 57
HTML_ASPJS_COMMENT_LINE     = 58
HTML_ASPJS_COMMENT_DOC      = 59
HTML_ASPJS_NUMBER           = 60
HTML_ASPJS_WORD             = 61
HTML_ASPJS_KEYWORD          = 62
HTML_ASPJS_STRING_DOUBLE    = 63
HTML_ASPJS_STRING_SINGLE    = 64
HTML_ASPJS_SYMBOL           = 65
HTML_ASPJS_EOL              = 66
HTML_ASPJS_REGEX            = 67

# LEXER_HTML :: Embedded VBS
HTML_VBS_START      = 70
HTML_VBS_DEFAULT    = 71
HTML_VBS_COMMENT    = 72
HTML_VBS_NUMBER     = 73
HTML_VBS_KEYWORD    = 74
HTML_VBS_STRING     = 75
HTML_VBS_IDENTIFIER = 76
HTML_VBS_EOL        = 77

# LEXER_HTML :: ASP VBS
HTML_ASPVBS_START       = 80
HTML_ASPVBS_DEFAULT     = 81
HTML_ASPVBS_COMMENT     = 82
HTML_ASPVBS_NUMBER      = 83
HTML_ASPVBS_KEYWORD     = 84
HTML_ASPVBS_STRING      = 85
HTML_ASPVBS_IDENTIFIER  = 86
HTML_ASPVBS_EOL         = 87

# LEXER_HTML :: Embedded Python
HTML_PY_START           = 90
HTML_PY_DEFAULT         = 91
HTML_PY_COMMENT_LINE    = 92
HTML_PY_NUMBER          = 93
HTML_PY_STRING_DOUBLE   = 94
HTML_PY_STRING_SINGLE   = 95
HTML_PY_KEYWORD         = 96
HTML_PY_TRIPLE_SINGLE   = 97
HTML_PY_TRIPLE_DOUBLE   = 98
HTML_PY_CLASS_STATEMENT = 99
HTML_PY_DEF_STATEMENT   = 100
HTML_PY_OPERATOR        = 101
HTML_PY_IDENTIFIER      = 102

# LEXER_HTML :: ASP Python
HTML_ASPPY_START           = 105
HTML_ASPPY_DEFAULT         = 106
HTML_ASPPY_COMMENT_LINE    = 107
HTML_ASPPY_NUMBER          = 108
HTML_ASPPY_STRING_DOUBLE   = 109
HTML_ASPPY_STRING_SINGLE   = 110
HTML_ASPPY_KEYWORD         = 111
HTML_ASPPY_TRIPLE_SINGLE   = 112
HTML_ASPPY_TRIPLE_DOUBLE   = 113
HTML_ASPPY_CLASS_STATEMENT = 114
HTML_ASPPY_DEF_STATEMENT   = 115
HTML_ASPPY_OPERATOR        = 116
HTML_ASPPY_IDENTIFIER      = 117

# LEXER_HTML :: PHP
HTML_PHP_DEFAULT        = 118
HTML_PHP_STRING_DOUBLE  = 119
HTML_PHP_STRING_SINGLE  = 120
HTML_PHP_KEYWORD        = 121
HTML_PHP_NUMBER         = 122
HTML_PHP_VARIABLE       = 123
HTML_PHP_COMMENT_BLOCK  = 124
HTML_PHP_COMMENT_LINE   = 125
HTML_PHP_EOL            = 126

# LEXER_XML Lexical states
XML_DEFAULT             = 0
XML_TAG                 = 1
XML_TAG_UNKNOWN         = 2
XML_ATTRIBUTE           = 3
XML_ATTRIBUTE_UNKNOWN   = 4
XML_NUMBER              = 5
XML_DOUBLE_STRING       = 6
XML_SINGLE_STRING       = 7
XML_OTHER               = 8
XML_COMMENT             = 9
XML_ENTITY              = 10
XML_TAG_END             = 11
XML_ID_START            = 12
XML_ID_END              = 13
XML_CDATA               = 17
XML_QUESTION            = 18
XML_UNQUOTED            = 19

# LEXER_PERL Lexical states
PERL_WHITE_SPACE     = 0
PERL_ERROR           = 1
PERL_COMMENT_LINE    = 2
PERL_POD             = 3
PERL_NUMBER          = 4
PERL_KEYWORD         = 5
PERL_STRING          = 6
PERL_CHARACTER       = 7
PERL_PUNCTUATION     = 8
PERL_PREPROCESSOR    = 9
PERL_OPERATOR        = 10
PERL_IDENTIFIER      = 11
PERL_SCALAR          = 12
PERL_ARRAY           = 13
PERL_HASH            = 14
PERL_SYMBOL_TABLE    = 15
PERL_REGEX           = 17
PERL_REGSUBST        = 18
PERL_LONG_QUOTE      = 19
PERL_BACKTICKS       = 20
PERL_DATA_SECTION    = 21
PERL_HERE_DELIM      = 22
PERL_HERE_Q          = 23
PERL_HERE_QQ         = 24
PERL_HERE_QX         = 25
PERL_STRING_Q        = 26
PERL_STRING_QQ       = 27
PERL_STRING_QX       = 28
PERL_STRING_QR       = 29
PERL_STRING_QW       = 30

# LEXER_SQL Lexical states
SQL_WHITE_SPACE   = 0
SQL_COMMENT_BLOCK = 1
SQL_COMMENT_LINE  = 2
SQL_COMMENT_DOC   = 3
SQL_NUMBER        = 4
SQL_KEYWORD       = 5
SQL_DOUBLE_STRING = 6
SQL_SINGLE_STRING = 7
SQL_SYMBOLS       = 8
SQL_PREPROCESSOR  = 9
SQL_OPERATOR      = 10
SQL_IDENTIFIER    = 11
SQL_STRING_EOL    = 12

# LEXER_VB Lexical states
VB_WHITE_SPACE   = 0
VB_COMMENT_BLOCK = 1
VB_COMMENT_LINE  = 2
VB_COMMENT_DOC   = 3
VB_NUMBER        = 4
VB_WORD          = 5
VB_STRING        = 6
VB_CHARACTER     = 7
VB_UUID          = 8
VB_PREPROCESSOR  = 9
VB_OPERATOR      = 10
VB_IDENTIFIER    = 11
VB_STRING_EOL    = 12

# LEXER_PROPERTIES Lexical states
PROPERTIES_DEFAULT      = 0
PROPERTIES_COMMENT      = 1
PROPERTIES_SECTION      = 2
PROPERTIES_OPERATOR     = 3
PROPERTIES_DEFAULT_VAL  = 4

# LEXER_ERRORLIST Lexical states
ERROR_DEFAULT       = 0
ERROR_PYTHON        = 1
ERROR_GCC           = 2
ERROR_MS            = 3
ERROR_CMD           = 4
ERROR_BORLAND       = 5
ERROR_PERL          = 6
ERROR_DIFF_CHANGED  = 10
ERROR_DIFF_ADDITION = 11
ERROR_DIFF_DELETION = 12
ERROR_DIFF_MESSAGE  = 13

# LEXER_MAKEFILE Lexical states
MAKEFILE_WHITE_SPACE  = 0
MAKEFILE_COMMENT      = 1
MAKEFILE_PREPROCESSOR = 2
MAKEFILE_IDENTIFIER   = 3
MAKEFILE_OPERATOR     = 4
MAKEFILE_IDEOL        = 9

# LEXER_BATCH Lexical states
BATCH_DEFAULT       = 0
BATCH_COMMENT       = 1
BATCH_WORD          = 2
BATCH_LABEL         = 3
BATCH_HIDE          = 4
BATCH_COMMAND       = 5
BATCH_IDENTIFIER    = 6
BATCH_OPERATOR      = 7

# LEXER_LATEX Lexical states
LATEX_WHITE_SPACE = 0
LATEX_COMMAND     = 1
LATEX_TAG         = 2
LATEX_MATH        = 3
LATEX_COMMENT     = 4

# LEXER_LUA Lexical states
LUA_WHITE_SPACE    = 0
LUA_COMMENT_BLOCK  = 1
LUA_COMMENT_LINE   = 2
LUA_COMMENT_DOC    = 3
LUA_NUMBER         = 4
LUA_KEYWORD        = 5
LUA_STRING         = 6
LUA_CHARACTER      = 7
LUA_LITERAL_STRING = 8
LUA_PREPROCESSOR   = 9
LUA_OPERATOR       = 10
LUA_IDENTIFIER     = 11
LUA_STRING_EOL     = 12

# LEXER_DIFF Lexical states
DIFF_DEFAULT    = 0
DIFF_COMMENT    = 1
DIFF_COMMAND    = 2
DIFF_FILES      = 3
DIFF_POSITION   = 4
DIFF_DEL_LINE   = 5
DIFF_ADD_LINE   = 6

# LEXER_CONF Lexical states
CONF_DEFAULT    = 0
CONF_COMMENT    = 1
CONF_NUMBER     = 2
CONF_IDENTIFIER = 3
CONF_EXTENSION  = 4
CONF_PARAMETER  = 5
CONF_STRING     = 6
CONF_OPERATOR   = 7
CONF_IP         = 8
CONF_DIRECTIVE  = 9

# LEXER_PASCAL Lexical states
PASCAL_WHITE_SPACE   = 0
PASCAL_COMMENT_BLOCK = 1
PASCAL_COMMENT_LINE  = 2
PASCAL_COMMENT_DOC   = 3
PASCAL_NUMBER        = 4
PASCAL_KEYWORD       = 5
PASCAL_DOUBLE_STRING = 6
PASCAL_SINGLE_STRING = 7
PASCAL_SYMBOLS       = 8
PASCAL_PREPROCESSOR  = 9

# LEXER_AVE Lexical states
AVE_DEFAULT = 0
AVE_COMMENT = 1
AVE_NUMBER = 2
AVE_WORD = 3
AVE_KEYWORD = 4
AVE_STATEMENT = 5
AVE_STRING = 6
AVE_ENUM = 7
AVE_STRINGEOL = 8
AVE_IDENTIFIER = 9
AVE_OPERATOR = 10

# LEXER_ADA Lexical states
ADA_DEFAULT = 0
ADA_COMMENT = 1
ADA_NUMBER = 2
ADA_WORD = 3
ADA_STRING = 4
ADA_CHARACTER = 5
ADA_OPERATOR = 6
ADA_IDENTIFIER = 7
ADA_STRINGEOL = 8
